Module: Shellout
- Defined in:
- lib/shellout.rb,
lib/shellout/menu.rb,
lib/shellout/table.rb,
lib/shellout/version.rb,
lib/shellout/calendar.rb,
lib/shellout/shadowbox.rb
Overview
You can mixin this module to get shortcuts to the various functionality provided by the classes below this namespace
Defined Under Namespace
Classes: Calendar, Menu, Shadowbox, Table
Constant Summary collapse
- VERSION =
'0.4'
Instance Method Summary collapse
-
#Calendar(*whatever) ⇒ Object
See doc for Shellout::Calendar.new.
-
#Menu(*whatever) ⇒ Object
See doc for Shellout::Menu.new.
-
#Shadowbox(*whatever) ⇒ Object
See doc for Shellout::Shadowbox.new.
-
#Table(*whatever) ⇒ Object
See doc for Shellout::Table.new.
Instance Method Details
#Calendar(*whatever) ⇒ Object
See doc for Shellout::Calendar.new
31 32 33 |
# File 'lib/shellout.rb', line 31 def Calendar(*whatever) Shellout::Calendar.new(*whatever) end |
#Menu(*whatever) ⇒ Object
See doc for Shellout::Menu.new
46 47 48 |
# File 'lib/shellout.rb', line 46 def Menu(*whatever) Shellout::Menu.new(*whatever) end |